@@ -1,6 +1,7 @@
 
 import argparse
 import subprocess
+from time import sleep
 
 from notebuild.shell import run_shell, run_shell_list
 from notejob.tasks import start
@@ -31,6 +32,7 @@ class JobScheduler:
 
     def restart(self):
         self.stop()
+        sleep(3)
         self.start()
 
 
